<template>
  <a-modal
    :title="title"
    :width="800"
    :visible="visible"
    :confirmLoading="confirmLoading"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form-model ref="form" :label-col="labelCol" :wrapper-col="wrapperCol" :model="model" :rules="validatorRules">
           <a-form-model-item label="项目名称" required prop="xmmc">
          <a-input v-model="model.xmmc" title="项目名称" disabled />
        </a-form-model-item>
        <a-form-model-item label="里程碑" required prop="lcb">
          <j-dict-select-tag v-model="model.lcb" title="里程碑" dictCode="lcb" placeholder="请选择里程碑" />
        </a-form-model-item>
        <a-form-model-item label="里程碑状态" required prop="lcbzt">
          <j-dict-select-tag v-model="model.lcbzt" title="里程碑状态" dictCode="lcbzt" placeholder="请选择里程碑状态" />
        </a-form-model-item>

        <a-form-model-item label="里程碑优先级" required prop="lcbyxj">
          <j-dict-select-tag
            v-model="model.lcbyxj"
            title="里程碑优先级"
            dictCode="lcbyxj"
            placeholder="请选择里程碑优先级"
          />
        </a-form-model-item>
      </a-form-model>
    </a-spin>
  </a-modal>
</template>

<script>
import { httpAction, getAction, postAction, putAction } from '@/api/manage'
export default {
  name: 'RoleModal',
  data() {
    return {
      title: '操作',
      visible: false,
      roleDisabled: false,
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 5 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
      confirmLoading: false,
      validatorRules: {
        lcb: [{ required: true, message: '请选择里程碑!' }],
        lcbzt: [{ required: true, message: '请输入里程碑状态!' }],
        lcbyxj: [{ required: true, message: '请输入里程碑优先级!' }],
      },
      url: {
        edit: '/pro/project/edit',
      },
    }
  },
  created() {},
  methods: {
    add() {
      this.edit()
    },
    edit(record) {
      let temp = {}
      temp.id = record.id
      temp.xmmc =record.xmmc
      temp.lcb = record.lcb
      temp.lcbzt = record.lcbzt
      temp.lcbyxj = record.lcbyxj
      this.model = Object.assign({}, temp)
      this.visible = true
      //编辑页面禁止修改角色编码
      if (this.model.id) {
        this.roleDisabled = true
      } else {
        this.roleDisabled = false
      }
    },
    close() {
      this.$refs.form.clearValidate()
      this.$emit('close')
      this.visible = false
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.$refs.form.validate((valid) => {
        if (valid) {
          that.confirmLoading = true
          putAction(this.url.edit, that.model)
            .then((res) => {
              if (res.success) {
                that.$message.success(res.message)
                that.$emit('ok')
              } else {
                that.$message.warning(res.message)
              }
            })
            .finally(() => {
              that.confirmLoading = false
              that.close()
            })
        } else {
          return false
        }
      })
    },
    handleCancel() {
      this.close()
    },
  },
}
</script>

<style scoped>
</style>